@@ -253,12 +253,14 @@ class IO_MQTT:
 
             client.subscribe([('temperature'), ('humidity')])
         """
-        validate_feed_key(feed_key)
         if shared_user is not None and feed_key is not None:
+            validate_feed_key(feed_key)
             self._client.subscribe("{0}/f/{1}".format(shared_user, feed_key))
         elif group_key is not None:
+            validate_feed_key(group_key)
             self._client.subscribe("{0}/g/{1}".format(self._user, group_key))
         elif feed_key is not None:
+            validate_feed_key(feed_key)
             self._client.subscribe("{0}/f/{1}".format(self._user, feed_key))
         else:
             raise AdafruitIO_MQTTError("Must provide a feed_key or group_key.")
@@ -333,12 +335,14 @@ class IO_MQTT:
             client.unsubscribe('temperature', shared_user='adabot')
 
         """
-        validate_feed_key(feed_key)
         if shared_user is not None and feed_key is not None:
+            validate_feed_key(feed_key)
             self._client.unsubscribe("{0}/f/{1}".format(shared_user, feed_key))
         elif group_key is not None:
+            validate_feed_key(group_key)
             self._client.unsubscribe("{0}/g/{1}".format(self._user, feed_key))
         elif feed_key is not None:
+            validate_feed_key(feed_key)
             self._client.unsubscribe("{0}/f/{1}".format(self._user, feed_key))
         else:
             raise AdafruitIO_MQTTError("Must provide a feed_key or group_key.")
